@@ -52,7 +52,7 @@ class KGamma: public KCModule
       /** Validate the loaded gamma values */
       bool validateGammaValues();
 
-    private slots:
+    private Q_SLOTS:
       /** Called if the user changesd something */
       void Changed() { emit changed(true); }
       /** Called if the user marked or unmarked the XF86Config checkbox */
